module GenericParser.BaseFunctions where

import Prelude (between, (-), (<), (<>), (==), (||), ($))

import Data.Array as A
import Data.String.CodeUnits (singleton)

concat :: Char -> String -> String
concat c rest = singleton c <> rest

id :: forall a. a -> a
id x = x

isDigit :: Char -> Boolean
isDigit = between '0' '9'

isLower :: Char -> Boolean
isLower = between 'a' 'z'

isUpper :: Char -> Boolean
isUpper = between 'A' 'Z'

isHexaDecimal :: Char -> Boolean
isHexaDecimal c = between '0' '9' c || between 'a' 'f' c || between 'A' 'F' c

isAlpha :: Char -> Boolean
isAlpha c = A.any (\f -> f c) [isLower, isUpper]

isAlphaNum :: Char -> Boolean
isAlphaNum c = A.any (\f -> f c) [isAlpha, isDigit]

isSpace :: Char -> Boolean
isSpace c = A.any (\v -> v == c) [' ', '\t', ' ', '\r', '\n']

repeat :: forall a. Int -> a -> Array a
repeat 0 _ = []
repeat n v = if n < 0 then [] else A.cons v $ repeat (n - 1) v
