-- | `EmailAddress` is a simplistic parser for email addresses.
-- | For a more serious parser, see the `RFC5322` module.
-- |
-- | STATUS: the parser works for very simplistic email addresses.
-- | This shouldn't be used in a serious environment.
module GenericParser.EmailAddress where

import Prelude (bind, pure, ($), (<>))

import Control.Alt ((<|>))
import Data.Either (Either(..))
import Data.Maybe (Maybe(..))
import Data.String.CodeUnits as CU

import GenericParser.Parser (Parser(..), char, item, current_input, failureError, parse, rollback, until)
import GenericParser.DomainParser.Common (DomainError)
import GenericParser.DomainParser (sub_eof)
-- ABNF core rules.
import GenericParser.RFC5234 (digit)
import GenericParser.SomeParsers (letter)

data EmailError
  = InvalidCharacter
  | InvalidDomain (Maybe DomainError)

-- | TODO: For now, `local_part` only checks that
-- | (a) the first character is a letter,
-- | (b) the last character is either a letter or a digit.
-- | The rest can be any letter, digit, '-' or '.'.
local_part :: Parser EmailError String
local_part = do firstchar <- letter
                rest <- until end (letter <|> digit <|> char '-' <|> char '.')
                lastchar <- letter <|> digit
                pure $ CU.fromCharArray $ [firstchar] <> rest <> [lastchar]
              where
                end :: forall e. Parser e Char
                end = do c <- item
                         _ <- char '@'
                         pure c

-- | `email` is the parser for email addresses.
email :: Parser EmailError String
email = do login <- local_part
           _ <- char '@'
           input <- current_input
           case parse sub_eof input of
             Left {error, position} ->
               Parser \_ -> failureError position (Just $ InvalidDomain error)
             Right {result, suffix} -> do
                       _ <- rollback suffix
                       pure $ login <> "@" <> result
