module GenericParser.SomeParsers where
import Prelude (Unit, bind, discard, negate, pure, unit, ($))

import Control.Alt ((<|>))
import Control.Plus (empty)
import Data.Array as A
import Data.Maybe (Maybe(..))
import Data.Int as Int
import Data.String as S
import Data.String.CodeUnits as CU

import GenericParser.Parser
import GenericParser.BaseFunctions (isAlpha, isAlphaNum, isLower, isSpace, isUpper)
import GenericParser.RFC5234 (digit)

lower :: forall e. Parser e Char
lower = sat isLower

upper :: forall e. Parser e Char
upper = sat isUpper

letter :: forall e. Parser e Char
letter = sat isAlpha

alphanum :: forall e. Parser e Char
alphanum = sat isAlphaNum

ident :: forall e. Parser e String
ident = do x  <- lower
           xs <- A.many alphanum
           pure (CU.fromCharArray $ A.cons x xs)

nat :: forall e. Parser e Int
nat = do xs <- A.some digit
         case Int.fromString (CU.fromCharArray xs) of
           Nothing -> empty
           Just x -> pure x

int :: forall e. Parser e Int
int = do _ <- char '-'
         n <- nat
         pure (-n)
       <|> nat

space :: forall e. Parser e Unit
space = do _ <- A.many (sat isSpace)
           pure unit

token :: forall e a. Parser e a -> Parser e a
token p = do space
             v <- p
             _ <- space
             pure v

identifier :: forall e. Parser e String
identifier = token ident

natural :: forall e. Parser e Int
natural = token nat

integer :: forall e. Parser e Int
integer = token int

symbol :: forall e. String -> Parser e String
symbol xs = token (string xs)

eof :: forall e. Parser e Unit
eof = Parser \input -> case S.length input.string of
  0 -> success input unit
  _ -> failure input.position
