module Test.TestValues where

domains :: Array String
domains
  = [ ""
    , "-"
    , "."
    , "a"
    , "a."
    , "a-"
    , "a.x"
    , "a2.org"
    , "a33.org"
    , "xblah.a.x"
    , "xblah.a2.org"
    , "xblah.a33.org"
    , "_dmarc.example.com"
    ]

ipv4_addresses :: Array String
ipv4_addresses
  = [ "10..1."
    , "10..1"
    , "1..2"
    , "1.2.3.4"
    , "192.168..1"
    , "1..2.3.4"
    , "1.5.10.255"
    , "100.200.300.400"
    ]

ipv6_addresses :: Array String
ipv6_addresses
  = [ "2001:0"
    , "2001::x:0"
    , "2001:x::0"
    , "2001::0"
    , "2001::1:"
    , "::"
    , "2001::"
    , "::1"
    , "2001:0db8:0000:0000:0000:8a2e:0370:7334:30:1035:3"
    , "2001:0db8:0000:0000:0000:8a2e:0370:7334"
    , "2001:0db8::8a2e:0370:7334"
    ]

valid_email_addresses_short :: Array String
valid_email_addresses_short
  = [ """simple@example.com"""
    , """very.common@example.com"""
    , """x@example.com """
    , """long.email-address-with-hyphens@and.subdomains.example.com"""
    , """user.name+tag+sorting@example.com """
    , """name/surname@example.com """
    , """admin@example """
    , """example@s.example """
    , """" "@example.org """
    , """"john..doe"@example.org """
    , """mailhost!username@example.org """
    , """"very.(),:;<>[]\".VERY.\"very@\\ \"very\".unusual"@strange.example.com """
    , """user%example.com@example.org """
    , """user-@example.org """
    , """postmaster@[123.123.123.123] """
    , """postmaster@[IPv6:2001:0db8:85a3:0000:0000:8a2e:0370:7334] """
    , """_test@[IPv6:2001:0db8:85a3:0000:0000:8a2e:0370:7334] """
    ]

valid_email_addresses :: Array String
valid_email_addresses
  = [ """simple@example.com"""
    , """very.common@example.com"""
    , """x@example.com (one-letter local-part)"""
    , """long.email-address-with-hyphens@and.subdomains.example.com"""
    , """user.name+tag+sorting@example.com (may be routed to user.name@example.com inbox depending on mail server)"""
    , """name/surname@example.com (slashes are a printable character, and allowed)"""
    , """admin@example (local domain name with no TLD, although ICANN highly discourages dotless email addresses[29])"""
    , """example@s.example (see the List of Internet top-level domains)"""
    , """" "@example.org (space between the quotes)"""
    , """"john..doe"@example.org (quoted double dot)"""
    , """mailhost!username@example.org (bangified host route used for uucp mailers)"""
    , """"very.(),:;<>[]\".VERY.\"very@\\ \"very\".unusual"@strange.example.com (include non-letters character AND multiple at sign, the first one being double quoted)"""
    , """user%example.com@example.org (% escaped mail route to user@example.com via example.org)"""
    , """user-@example.org (local-part ending with non-alphanumeric character from the list of allowed printable characters)"""
    , """postmaster@[123.123.123.123] (IP addresses are allowed instead of domains when in square brackets, but strongly discouraged)"""
    , """postmaster@[IPv6:2001:0db8:85a3:0000:0000:8a2e:0370:7334] (IPv6 uses a different syntax)"""
    , """_test@[IPv6:2001:0db8:85a3:0000:0000:8a2e:0370:7334] (begin with underscore different syntax)"""
    ]
